==> snareinstall-2.1.tar.gz: snareinstall-2.1/uninstall.sh <==
#!/bin/sh

########################################################################
#    
#    (c) 2001-2003 Intersect Alliance Pty Ltd
# 
#   This script will automate the installation of the snare audit daemon.
#   
#   Version 1.0
#    
#    Usage: ./uninstall.sh
#
########################################################################

########################################################################
#   Check that the user has an effective userid of 0 (root) 
########################################################################

root_check()
{
     id | grep -c uid=0 > /dev/null
     RETVAL=$?

	if [ $RETVAL -gt 0 ]
	then
           echo "You need to be root to run this script. Terminating script."
           exit 7
        else
           echo "Confirmed your are logged in as root"
	fi

}

########################################################################
#   This routine will copy the key audit_[control|class|event]  
#   and the /etc/init.d/audit files to the /etc/security directory
#   and rename them to ".snare-backup". If they exist, it will not back them up.
#   The point of this approach is to backup the old BSM files, and not
#   the snarecore files. If a recovery is required, the user can then 
#   recover to an old BSM state. 
########################################################################

restore_key_files()
{
   echo "Restoring key files..........."

   echo "Restoring oringinal /etc/init.d/audit..."
   if [ -f /etc/security/audit.snare-backup ]
   then
      cp /etc/security/audit.snare-backup /etc/init.d/audit
      RETVAL=$?
      if [ $RETVAL -gt 0 ]
      then
        echo "Unable to restore /etc/init.d/audit to its original value."
      fi
   else
	echo "Cannot find /etc/init.d/audit.snare-backup. Cannot restore."
   fi 

   echo "Restoring oringinal /etc/init.d/audit_control..."
   if [ -f /etc/security/audit_control.snare-backup ]
   then
      cp /etc/security/audit_control.snare-backup /etc/init.d/audit_control
      RETVAL=$?
      if [ $RETVAL -gt 0 ]
      then
        echo "Unable to restore /etc/init.d/audit_control to its original value."
      fi
   else
	echo "Cannot find /etc/init.d/audit_control.snare-backup. Cannot restore."
   fi 

   echo "Restoring oringinal /etc/init.d/audit_class..."
   if [ -f /etc/security/audit_class.snare-backup ]
   then
      cp /etc/security/audit_class.snare-backup /etc/init.d/audit_class
      RETVAL=$?
      if [ $RETVAL -gt 0 ]
      then
        echo "Unable to restore /etc/init.d/audit_class to its original value."
      fi
   else
	echo "Cannot find /etc/init.d/audit_class.snare-backup. Cannot restore."
   fi 

   echo "Restoring oringinal /etc/init.d/audit_event..."
   if [ -f /etc/security/audit_event.snare-backup ]
   then
      cp /etc/security/audit_event.snare-backup /etc/init.d/audit_event
      RETVAL=$?
      if [ $RETVAL -gt 0 ]
      then
        echo "Unable to restore /etc/init.d/audit_event to its original value."
      fi
   else
	echo "Cannot find /etc/init.d/audit_event.snare-backup. Cannot restore."
   fi 

   echo "Removing snarecore binary..."
   if [ -f /etc/security/snarecore ]
   then
	rm /etc/security/snarecore 2>/dev/null
        echo "Done."
   fi

   if [ -f /usr/bin/snare ]
   then
        echo "Removing snare GUI binary..."
        rm /usr/bin/snare 2>/dev/null
        echo "Done."
   fi

   echo "I will leave the snare configuration file (/etc/security/snare.conf) - please remove it manually if you intend to permanently remove SNARE..."
   # if [ -f /etc/security/snare.conf ]
   # then
#	rm /etc/security/snare.conf 2>/dev/null
#        echo "Done."
#   fi
}

/etc/init.d/snare stop
/etc/init.d/audit stop

root_check
restore_key_files

# Remove the snare-specific startup scripts
rm /etc/init.d/snare 2>/dev/null
rm /etc/rc0.d/K33snare 2>/dev/null
rm /etc/rc1.d/K33snare 2>/dev/null
rm /etc/rc2.d/S99zsnare 2>/dev/null

# remove documentation
rm /usr/share/doc/snare-core-0.9/doc/index.html
rm /usr/share/doc/snare-core-0.9/doc/figure*png
rmdir /usr/share/doc/snare-core-0.9/doc 2>/dev/null
rmdir /usr/share/doc/snare-core-0.9 2>/dev/null
rmdir /usr/share/doc 2>/dev/null

rm /var/run/snarecore.pid 2>/dev/null

==> snareinstall-2.3.tar.gz: snareinstall-2.3/uninstall.sh <==
#!/bin/sh

########################################################################
#    
#    (c) 2001-2004 Intersect Alliance Pty Ltd
# 
#   This script will automate the installation of the snare audit daemon.
#   
#   Version 1.1
#    
#    Usage: ./uninstall.sh
#
########################################################################

########################################################################
#   Check that the user has an effective userid of 0 (root) 
########################################################################

root_check()
{
     id | grep -c uid=0 > /dev/null
     RETVAL=$?

	if [ $RETVAL -gt 0 ]
	then
           echo "You need to be root to run this script. Terminating script."
           exit 7
        else
           echo "Confirmed your are logged in as root"
	fi

}

########################################################################
#   This routine will copy the key audit_[control|class|event]  
#   and the /etc/init.d/audit files to the /etc/security directory
#   and rename them to ".snare-backup". If they exist, it will not back them up.
#   The point of this approach is to backup the old BSM files, and not
#   the snarecore files. If a recovery is required, the user can then 
#   recover to an old BSM state. 
########################################################################

restore_key_files()
{
   echo "Restoring key files..........."

   echo "Restoring oringinal /etc/init.d/audit..."
   if [ -f /etc/security/audit.snare-backup ]
   then
      cp /etc/security/audit.snare-backup /etc/init.d/audit
      RETVAL=$?
      if [ $RETVAL -gt 0 ]
      then
        echo "Unable to restore /etc/init.d/audit to its original value."
      fi
   else
	echo "Cannot find /etc/init.d/audit.snare-backup. Cannot restore."
   fi 

   echo "Restoring oringinal /etc/init.d/audit_control..."
   if [ -f /etc/security/audit_control.snare-backup ]
   then
      cp /etc/security/audit_control.snare-backup /etc/security/audit_control
      RETVAL=$?
      if [ $RETVAL -gt 0 ]
      then
        echo "Unable to restore /etc/security/audit_control to its original value."
      fi
   else
	echo "Cannot find /etc/security/audit_control.snare-backup. Cannot restore."
   fi 

   echo "Restoring oringinal /etc/security/audit_class..."
   if [ -f /etc/security/audit_class.snare-backup ]
   then
      cp /etc/security/audit_class.snare-backup /etc/security/audit_class
      RETVAL=$?
      if [ $RETVAL -gt 0 ]
      then
        echo "Unable to restore /etc/security/audit_class to its original value."
      fi
   else
	echo "Cannot find /etc/security/audit_class.snare-backup. Cannot restore."
   fi 

   echo "Restoring oringinal /etc/security/audit_event..."
   if [ -f /etc/security/audit_event.snare-backup ]
   then
      cp /etc/security/audit_event.snare-backup /etc/security/audit_event
      RETVAL=$?
      if [ $RETVAL -gt 0 ]
      then
        echo "Unable to restore /etc/security/audit_event to its original value."
      fi
   else
	echo "Cannot find /etc/security/audit_event.snare-backup. Cannot restore."
   fi 

   echo "Removing snarecore binary..."
   if [ -f /etc/security/snarecore ]
   then
	rm /etc/security/snarecore 2>/dev/null
        echo "Done."
   fi

   if [ -f /usr/bin/snare ]
   then
        echo "Removing snare GUI binary..."
        rm /usr/bin/snare 2>/dev/null
        echo "Done."
   fi

   echo "Removing snare backup files."
   rm -f /etc/security/*.snare-backup
   echo "Done."

   echo "I will leave the snare configuration file (/etc/security/snare.conf) - please remove it manually if you intend to permanently remove SNARE..."
}

/etc/init.d/snare stop
/etc/init.d/audit stop

root_check
restore_key_files

# Remove the snare-specific startup scripts
rm /etc/init.d/snare 2>/dev/null
rm /etc/rc0.d/K33snare 2>/dev/null
rm /etc/rc1.d/K33snare 2>/dev/null
rm /etc/rc2.d/S99zsnare 2>/dev/null

# remove documentation
rm /usr/share/doc/snare-for-solaris/doc/*
rmdir /usr/share/doc/snare-for-solaris/doc 2>/dev/null
rmdir /usr/share/doc/snare-for-solaris 2>/dev/null
rmdir /usr/share/doc 2>/dev/null

rm /var/run/snarecore.pid 2>/dev/null
rm /etc/security/snare_uninstall.sh
